import { ActPlugin } from '@act/plugins';

(function() {
  const plugin = new ActPlugin('Your Amazing Plugin');
  const nameHeader = document.getElementById('name');
  const tableElement = document.getElementById('table');
  const directionsFrame = document.getElementById('iframe');
  const mapsButton = document.getElementById('mapsButton');
  const loading = document.querySelector('div.overlay');

  directionsFrame.addEventListener('load', () => {
    loading.hidden = true;
  });

  mapsButton.addEventListener('click', () => {
    if (directionsFrame.hidden) {
      directionsFrame.hidden = false;
    } else {
      directionsFrame.hidden = true;
    }
  })

  function getMapsUrl(address) {
    // Build the Google Maps url based on the passed Your Amazing Plugin Contact entity
    let addressString = '';

    const {
      line1,
      city,
      state,
      postalCode,
    } = address;

    addressString = encodeURIComponent(`${line1} ${city},${state} ${postalCode}`);

    // TODO: Add your own key to the following text then place after the ?
    // key={YOUR_KEY_HERE}&
    return `https://www.google.com/maps/embed/v1/search?q=${addressString}`
  }

  plugin.init(window).then(() => {
    tableElement.addEventListener('rowselect', ({ detail }) => {
      // Get current user's location based on browser
      loading.hidden = false;
      const url = getMapsUrl(detail);
      directionsFrame.src = url;
    });
  
    plugin.context$.subscribe((contact) => {
      nameHeader.innerText = contact.fullName;
      const data = [];
      if (contact.businessAddress && contact.businessAddress.line1) {
        data.push(contact.businessAddress);
      }
      if (contact.homeAddress && contact.homeAddress.line1) {
        data.push(contact.homeAddress);
      }
      tableElement.data = data;
      tableElement.requestUpdate();
    });
  }, (err) => console.error(err));
})();